# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field


# Modal mode. Clicks outside do not pass through to underlying elements. Restricts
# focus to the tooltip. Back button on Android and back gesture on iOS close the
# tooltip.
class DivTooltipModeModal(BaseDiv):

    def __init__(
        self, *,
        type: str = "modal",
        **kwargs: typing.Any,
    ):
        super().__init__(
            type=type,
            **kwargs,
        )

    type: str = Field(default="modal")


DivTooltipModeModal.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field


# Hides the tooltip.
class DivActionHideTooltip(BaseDiv):

    def __init__(
        self, *,
        type: str = "hide_tooltip",
        id: typing.Optional[typing.Union[Expr, str]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            type=type,
            id=id,
            **kwargs,
        )

    type: str = Field(default="hide_tooltip")
    id: typing.Union[Expr, str] = Field(
        description="Tooltip ID.",
    )


DivActionHideTooltip.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field


class DivContentAlignmentHorizontal(str, enum.Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"
    START = "start"
    END = "end"
    SPACE_BETWEEN = "space-between"
    SPACE_AROUND = "space-around"
    SPACE_EVENLY = "space-evenly"



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing
from typing import Union

from pydivkit.core import BaseDiv, Expr, Field

from . import (
    div_action_animator_start, div_action_animator_stop,
    div_action_array_insert_value, div_action_array_remove_value,
    div_action_array_set_value, div_action_clear_focus,
    div_action_copy_to_clipboard, div_action_dict_set_value,
    div_action_download, div_action_focus_element, div_action_hide_tooltip,
    div_action_scroll_by, div_action_scroll_to, div_action_set_state,
    div_action_set_stored_value, div_action_set_variable,
    div_action_show_tooltip, div_action_submit, div_action_timer,
    div_action_update_structure, div_action_video,
)


DivActionTyped = Union[
    div_action_animator_start.DivActionAnimatorStart,
    div_action_animator_stop.DivActionAnimatorStop,
    div_action_array_insert_value.DivActionArrayInsertValue,
    div_action_array_remove_value.DivActionArrayRemoveValue,
    div_action_array_set_value.DivActionArraySetValue,
    div_action_clear_focus.DivActionClearFocus,
    div_action_copy_to_clipboard.DivActionCopyToClipboard,
    div_action_dict_set_value.DivActionDictSetValue,
    div_action_download.DivActionDownload,
    div_action_focus_element.DivActionFocusElement,
    div_action_hide_tooltip.DivActionHideTooltip,
    div_action_scroll_by.DivActionScrollBy,
    div_action_scroll_to.DivActionScrollTo,
    div_action_set_state.DivActionSetState,
    div_action_set_stored_value.DivActionSetStoredValue,
    div_action_set_variable.DivActionSetVariable,
    div_action_show_tooltip.DivActionShowTooltip,
    div_action_submit.DivActionSubmit,
    div_action_timer.DivActionTimer,
    div_action_update_structure.DivActionUpdateStructure,
    div_action_video.DivActionVideo,
]



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field


# Filter based on [calculated expressions](../../expressions).
class DivInputFilterExpression(BaseDiv):

    def __init__(
        self, *,
        type: str = "expression",
        condition: typing.Optional[typing.Union[Expr, bool]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            type=type,
            condition=condition,
            **kwargs,
        )

    type: str = Field(default="expression")
    condition: typing.Union[Expr, bool] = Field(
        description=(
            "[Calculated expression](../../expressions) used to verify "
            "the validity of thevalue."
        ),
    )


DivInputFilterExpression.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field

from . import div_action_scroll_destination


# Scrolls to a position or switches to the container element specified by the
# `destination` parameter.
class DivActionScrollTo(BaseDiv):

    def __init__(
        self, *,
        type: str = "scroll_to",
        animated: typing.Optional[typing.Union[Expr, bool]] = None,
        destination: typing.Optional[div_action_scroll_destination.DivActionScrollDestination] = None,
        id: typing.Optional[typing.Union[Expr, str]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            type=type,
            animated=animated,
            destination=destination,
            id=id,
            **kwargs,
        )

    type: str = Field(default="scroll_to")
    animated: typing.Optional[typing.Union[Expr, bool]] = Field(
        description="Enables scrolling animation.",
    )
    destination: div_action_scroll_destination.DivActionScrollDestination = Field(
        description=(
            "Defines the scrolling end position:`index`: Scroll to the "
            "element with the indexprovided in `value``offset`: Scroll "
            "to the position specified in `value` andmeasured in `dp` "
            "from the start of the container. Applies only "
            "in`gallery`;`start`: Scroll to the container start;`end`: "
            "Scroll to the containerend."
        ),
    )
    id: typing.Union[Expr, str] = Field(
        description="ID of the element where the action should be performed.",
    )


DivActionScrollTo.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field


# Fixed aspect ratio. The element's height is calculated based on the width,
# ignoring the `height` value.
class DivAspect(BaseDiv):

    def __init__(
        self, *,
        ratio: typing.Optional[typing.Union[Expr, float]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            ratio=ratio,
            **kwargs,
        )

    ratio: typing.Union[Expr, float] = Field(
        description="`height = width / ratio`.",
    )


DivAspect.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field

from . import (
    div_action, div_animation_direction, div_animation_interpolator, div_count,
)


# Numeric value animator.
class DivNumberAnimator(BaseDiv):

    def __init__(
        self, *,
        type: str = "number_animator",
        cancel_actions: typing.Optional[typing.Sequence[div_action.DivAction]] = None,
        direction: typing.Optional[typing.Union[Expr, div_animation_direction.DivAnimationDirection]] = None,
        duration: typing.Optional[typing.Union[Expr, int]] = None,
        end_actions: typing.Optional[typing.Sequence[div_action.DivAction]] = None,
        end_value: typing.Optional[typing.Union[Expr, float]] = None,
        id: typing.Optional[typing.Union[Expr, str]] = None,
        interpolator: typing.Optional[typing.Union[Expr, div_animation_interpolator.DivAnimationInterpolator]] = None,
        repeat_count: typing.Optional[div_count.DivCount] = None,
        start_delay: typing.Optional[typing.Union[Expr, int]] = None,
        start_value: typing.Optional[typing.Union[Expr, float]] = None,
        variable_name: typing.Optional[typing.Union[Expr, str]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            type=type,
            cancel_actions=cancel_actions,
            direction=direction,
            duration=duration,
            end_actions=end_actions,
            end_value=end_value,
            id=id,
            interpolator=interpolator,
            repeat_count=repeat_count,
            start_delay=start_delay,
            start_value=start_value,
            variable_name=variable_name,
            **kwargs,
        )

    type: str = Field(default="number_animator")
    cancel_actions: typing.Optional[typing.Sequence[div_action.DivAction]] = Field(
        description=(
            "Actions performed when the animation is canceled. For "
            "example, when a commandwith the \'animator_stop\' type is "
            "received."
        ),
    )
    direction: typing.Optional[typing.Union[Expr, div_animation_direction.DivAnimationDirection]] = Field(
        description=(
            "Animation direction. Determines whether the animation "
            "should be played forward,backward, or alternate between "
            "forward and backward."
        ),
    )
    duration: typing.Union[Expr, int] = Field(
        description="Animation duration in milliseconds.",
    )
    end_actions: typing.Optional[typing.Sequence[div_action.DivAction]] = Field(
        description="Actions when the animation is completed.",
    )
    end_value: typing.Union[Expr, float] = Field(
        description="The value the variable will have when the animation ends.",
    )
    id: typing.Union[Expr, str] = Field(
        description="Animator ID.",
    )
    interpolator: typing.Optional[typing.Union[Expr, div_animation_interpolator.DivAnimationInterpolator]] = Field(
        description="Animated value interpolation function.",
    )
    repeat_count: typing.Optional[div_count.DivCount] = Field(
        description=(
            "Number of times the animation will repeat before stopping. "
            "A value of `0` enablesinfinite looping."
        ),
    )
    start_delay: typing.Optional[typing.Union[Expr, int]] = Field(
        description="Delay before the animation is launched in milliseconds.",
    )
    start_value: typing.Optional[typing.Union[Expr, float]] = Field(
        description=(
            "The value the variable will have when the animation starts. "
            "If the property isn\'tspecified, the current value of the "
            "variable will be used."
        ),
    )
    variable_name: typing.Union[Expr, str] = Field(
        description="Name of the variable being animated.",
    )


DivNumberAnimator.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field


class DivEvaluableType(str, enum.Enum):
    STRING = "string"
    INTEGER = "integer"
    NUMBER = "number"
    BOOLEAN = "boolean"
    DATETIME = "datetime"
    COLOR = "color"
    URL = "url"
    DICT = "dict"
    ARRAY = "array"



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field


# Mask for entering text with a fixed number of characters.
class DivFixedLengthInputMask(BaseDiv):

    def __init__(
        self, *,
        type: str = "fixed_length",
        always_visible: typing.Optional[typing.Union[Expr, bool]] = None,
        pattern: typing.Optional[typing.Union[Expr, str]] = None,
        pattern_elements: typing.Optional[typing.Sequence[DivFixedLengthInputMaskPatternElement]] = None,
        raw_text_variable: typing.Optional[typing.Union[Expr, str]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            type=type,
            always_visible=always_visible,
            pattern=pattern,
            pattern_elements=pattern_elements,
            raw_text_variable=raw_text_variable,
            **kwargs,
        )

    type: str = Field(default="fixed_length")
    always_visible: typing.Optional[typing.Union[Expr, bool]] = Field(
        description=(
            "If this option is enabled, the text field contains the mask "
            "before being filledin."
        ),
    )
    pattern: typing.Union[Expr, str] = Field(
        description=(
            "String that sets the text input template. For example, the "
            "`+7 (###) ###-##-#`template for a phone number."
        ),
    )
    pattern_elements: typing.Sequence[DivFixedLengthInputMaskPatternElement] = Field(
        min_items=1, 
        description=(
            "Template decoding is a description of the characters that "
            "will be replaced withuser input."
        ),
    )
    raw_text_variable: typing.Union[Expr, str] = Field(
        description="Name of the variable to store the unprocessed value.",
    )


# Template decoding is a description of the characters that will be replaced with
# user input.
class DivFixedLengthInputMaskPatternElement(BaseDiv):

    def __init__(
        self, *,
        key: typing.Optional[typing.Union[Expr, str]] = None,
        placeholder: typing.Optional[typing.Union[Expr, str]] = None,
        regex: typing.Optional[typing.Union[Expr, str]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            key=key,
            placeholder=placeholder,
            regex=regex,
            **kwargs,
        )

    key: typing.Union[Expr, str] = Field(
        min_length=1, 
        description=(
            "A character in the template that will be replaced with a "
            "user-defined character."
        ),
    )
    placeholder: typing.Optional[typing.Union[Expr, str]] = Field(
        min_length=1, 
        description=(
            "The character that\'s displayed in the input field where "
            "the user is expected toenter text. This is used if mask "
            "display is enabled."
        ),
    )
    regex: typing.Optional[typing.Union[Expr, str]] = Field(
        description=(
            "Regular expression for validating character inputs. For "
            "example, when a mask isdigit-only."
        ),
    )


DivFixedLengthInputMaskPatternElement.update_forward_refs()


DivFixedLengthInputMask.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field

from . import div_typed_value


# Set values ​​in a variable of type array or dictionary with different nesting.
class DivActionUpdateStructure(BaseDiv):

    def __init__(
        self, *,
        type: str = "update_structure",
        path: typing.Optional[typing.Union[Expr, str]] = None,
        value: typing.Optional[div_typed_value.DivTypedValue] = None,
        variable_name: typing.Optional[typing.Union[Expr, str]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            type=type,
            path=path,
            value=value,
            variable_name=variable_name,
            **kwargs,
        )

    type: str = Field(default="update_structure")
    path: typing.Union[Expr, str] = Field(
        description=(
            "Path within an array/dictionary where a value needs to be "
            "set. Path format: Eachpath element is separated by a \'/\' "
            "symbol.Path elements can be of two types: anindex of an "
            "element in an array, starting from 0 or dictionary keys in "
            "the formof arbitrary strings.The path is read from left to "
            "right, each element determinesthe transition to the next "
            "level of nesting.Example path: `key/0/inner_key/1`."
        ),
    )
    value: div_typed_value.DivTypedValue = Field(
        description="Value set into dictionary/array.",
    )
    variable_name: typing.Union[Expr, str] = Field(
        description="Variable name of array or dictionary type.",
    )


DivActionUpdateStructure.update_forward_refs()
